package org.apache.bcel.util;

package .var.folders.cl.9twcgjfx4vsg5zl73c6wxmvm0000gn.T;

import java.util.LinkedHashMap;
import org.apache.bcel.classfile.JavaClass;
import org.apache.bcel.util.AbstractClassPathRepository;
import org.apache.bcel.util.ClassPath;

public class LruCacheClassPathRepository extends AbstractClassPathRepository {
  private final LinkedHashMap<String, JavaClass> loadedClasses;
  
  public LruCacheClassPathRepository(ClassPath path, int cacheSize) {
    super(path);
    if (cacheSize < 1)
      throw new IllegalArgumentException("cacheSize must be a positive number."); 
    int initialCapacity = (int)(0.75D * cacheSize);
    boolean accessOrder = true;
    this.loadedClasses = (LinkedHashMap<String, JavaClass>)new Object(this, initialCapacity, cacheSize, true, cacheSize);
  }
  
  public void clear() {
    this.loadedClasses.clear();
  }
  
  public JavaClass findClass(String className) {
    return this.loadedClasses.get(className);
  }
  
  public void removeClass(JavaClass javaClass) {
    this.loadedClasses.remove(javaClass.getClassName());
  }
  
  public void storeClass(JavaClass javaClass) {
    this.loadedClasses.put(javaClass.getClassName(), javaClass);
    javaClass.setRepository(this);
  }
}
